@@ -1,5 +1,3 @@
-from __future__ import print_function, division, absolute_import
-from __future__ import unicode_literals
 from fontTools.feaLib.error import FeatureLibError
 from fontTools.feaLib.lexer import Lexer, IncludingLexer, NonIncludingLexer
 from fontTools.misc.encodingTools import getEncoding
@@ -978,14 +976,14 @@ class Parser(object):
     def parse_name_(self):
         platEncID = None
         langID = None
-        if self.next_token_type_ == Lexer.NUMBER:
-            platformID = self.expect_number_()
+        if self.next_token_type_ in Lexer.NUMBERS:
+            platformID = self.expect_any_number_()
             location = self.cur_token_location_
             if platformID not in (1, 3):
                 raise FeatureLibError("Expected platform id 1 or 3", location)
-            if self.next_token_type_ == Lexer.NUMBER:
-                platEncID = self.expect_number_()
-                langID = self.expect_number_()
+            if self.next_token_type_ in Lexer.NUMBERS:
+                platEncID = self.expect_any_number_()
+                langID = self.expect_any_number_()
         else:
             platformID = 3
             location = self.cur_token_location_
@@ -1008,7 +1006,7 @@ class Parser(object):
 
     def parse_nameid_(self):
         assert self.cur_token_ == "nameid", self.cur_token_
-        location, nameID = self.cur_token_location_, self.expect_number_()
+        location, nameID = self.cur_token_location_, self.expect_any_number_()
         if nameID > 32767:
             raise FeatureLibError("Name id value cannot be greater than 32767",
                                   self.cur_token_location_)
@@ -1352,7 +1350,7 @@ class Parser(object):
 
     def parse_cvCharacter_(self, tag):
         assert self.cur_token_ == "Character", self.cur_token_
-        location, character = self.cur_token_location_, self.expect_decimal_or_hexadecimal_()
+        location, character = self.cur_token_location_, self.expect_any_number_()
         self.expect_symbol_(";")
         if not (0xFFFFFF >= character >= 0):
             raise FeatureLibError("Character value must be between "
@@ -1558,13 +1556,19 @@ class Parser(object):
             return self.cur_token_
         raise FeatureLibError("Expected a name", self.cur_token_location_)
 
-    # TODO: Don't allow this method to accept hexadecimal values
     def expect_number_(self):
         self.advance_lexer_()
         if self.cur_token_type_ is Lexer.NUMBER:
             return self.cur_token_
         raise FeatureLibError("Expected a number", self.cur_token_location_)
 
+    def expect_any_number_(self):
+        self.advance_lexer_()
+        if self.cur_token_type_ in Lexer.NUMBERS:
+            return self.cur_token_
+        raise FeatureLibError("Expected a decimal, hexadecimal or octal number",
+                              self.cur_token_location_)
+
     def expect_float_(self):
         self.advance_lexer_()
         if self.cur_token_type_ is Lexer.FLOAT:
@@ -1572,7 +1576,6 @@ class Parser(object):
         raise FeatureLibError("Expected a floating-point number",
                               self.cur_token_location_)
 
-    # TODO: Don't allow this method to accept hexadecimal values
     def expect_decipoint_(self):
         if self.next_token_type_ == Lexer.FLOAT:
             return self.expect_float_()
@@ -1582,18 +1585,6 @@ class Parser(object):
             raise FeatureLibError("Expected an integer or floating-point number",
                                   self.cur_token_location_)
 
-    def expect_decimal_or_hexadecimal_(self):
-        # the lexer returns the same token type 'NUMBER' for either decimal or
-        # hexadecimal integers, and casts them both to a `int` type, so it's
-        # impossible to distinguish the two here. This method is implemented
-        # the same as `expect_number_`, only it gives a more informative
-        # error message
-        self.advance_lexer_()
-        if self.cur_token_type_ is Lexer.NUMBER:
-            return self.cur_token_
-        raise FeatureLibError("Expected a decimal or hexadecimal number",
-                              self.cur_token_location_)
-
     def expect_string_(self):
         self.advance_lexer_()
         if self.cur_token_type_ is Lexer.STRING:
