@@ -1,6 +1,6 @@
-from __future__ import print_function, division, absolute_import
 from fontTools.misc.py23 import *
+import sys
 from fontTools.subset import main
 
 if __name__ == '__main__':
-	main()
+    sys.exit(main())
